@@ -1,7 +1,7 @@
 # This file is part of the authentication_totp Tryton module.
 # Please see the COPYRIGHT and README.rst files at the top level of this
 # package for full copyright notices, license terms and support information.
-from trytond.exceptions import LoginException, UserError, UserWarning
+from trytond.exceptions import LoginException, UserError
 from trytond.i18n import gettext
 
 
@@ -26,9 +26,5 @@ class TOTPInvalidSecretError(UserError):
     "Raised when the secret is not of the right form"
 
 
-class TOTPKeyTooShortWarning(UserWarning):
-    "Warns the user that the TOTP secret key is too short"
-
-
 class TOTPKeyTooShortError(UserError):
     "Raised when the TOTP secret key is too short"
